@@ -3,9 +3,12 @@
 
 import logging
 
-from tornado import httputil
+try:
+    from tornado import httputil
 
-from six.moves.urllib.parse import urlparse
+    from six.moves.urllib.parse import urlparse
+except ImportError:
+    logging.warning('Could not import some dependencies. Probably setup.py installing holmes...')
 
 EMPTY_DOMAIN_RESULT = ('', '')
 
@@ -85,3 +88,20 @@ def get_status_code_title(status_code):
             title = 'Unknown'
 
     return title
+
+
+def is_valid(url):
+    try:
+        return urlparse(url)
+    except ValueError:
+        return None
+
+
+def count_url_levels(url):
+    parse = is_valid(url)
+    if parse:
+        path = parse.path
+        if path.startswith('/'):
+            path = path[1:]
+        return len(path.split('/'))
+    return None
